function frm_addroom_public(){};

frm_addroom_public.prototype = {
    __constructor: async function(view){

		view.title('CHAT::ADD_ROOM_PUBLIC_CAPTION');

		await view.buttons({
            'btn_next':{value:'FORM_BUTTONS::CREATE', css:'color1', disabled: true, onclick:function(){
				view.parent._final({
					type:'public',
					name:this.name._value().trim(),
					group:this.group._getDataValue()
				});
            }.bind(this)},
            'btn_cancel':{value:'FORM_BUTTONS::CANCEL'}
		});

		var groups = view.parent._getGroups();

		this.group._fill(groups);
		this.group._onchange = function() {
			view.parent.btn_next._disabled(!this.group._getDataValue() || !this.name._value());
		}.bind(this);
		if (groups.length === 1) {
			this.group._value(0);
		}

		this.name._restrict('![/\\\\:?"<>|~]+','','^.{1,255}$');
		this.name.__eIN.setAttribute('maxlength', 255);
		this.name._onerror = function(b){
			view.parent.btn_next._disabled(b || !this.group._getDataValue());
		}.bind(this);
		this.name._onsubmit = async function(){
			if (await this.__check())
				view.parent.btn_next._onclick();
		};
	}
};